"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var create_scheme_1 = require("./utility/create-scheme");
var get_diff_1 = require("./utility/get-diff");
var ChangesetHelper = /** @class */ (function () {
    function ChangesetHelper() {
    }
    /**
     * Creates a changeset between two objects.
     * The report contains the paths to all differing properties and is divided into "additions", "changes" and "deletions".
     * It also contains a Boolean indicating equality for quick access.
     */
    ChangesetHelper.compare = function (a, b) {
        var mapA = ChangesetHelper.createObjectMap(a), mapB = ChangesetHelper.createObjectMap(b);
        var diff = (0, get_diff_1.default)(mapA, mapB);
        diff.equals = !(diff.additions.length | diff.changes.length | diff.deletions.length);
        return diff;
    };
    /**
     * Returns a wrapper promise for the "compare" method.
     */
    ChangesetHelper.compareAsync = function (a, b) {
        return new Promise(function (resolve) {
            resolve(ChangesetHelper.compare(a, b));
        });
    };
    /**
     * Creates a changeset between two objects, but only returns if the objects are equal.
     */
    ChangesetHelper.isEqual = function (a, b) {
        return ChangesetHelper.compare(a, b).equals;
    };
    /**
     * Creates a changeset between two objects, but only returns the additions.
     */
    ChangesetHelper.getAdditions = function (a, b) {
        return ChangesetHelper.compare(a, b).additions;
    };
    /**
     * Creates a changeset between two objects, but only returns the changes.
     */
    ChangesetHelper.getChanges = function (a, b) {
        return ChangesetHelper.compare(a, b).changes;
    };
    /**
     * Creates a changeset between two objects, but only returns the deletions.
     */
    ChangesetHelper.getDeletions = function (a, b) {
        return ChangesetHelper.compare(a, b).deletions;
    };
    /**
     * Creates scheme between an object.
     * The object properties will be represented by a 1-dimensional map.
    */
    ChangesetHelper.createObjectMap = function (source) {
        var rawScheme = (0, create_scheme_1.default)(source), map = new Map();
        rawScheme.forEach(function (path) {
            map.set(path.join('.'), ChangesetHelper.getProperty(source, path));
        });
        return map;
    };
    /**
     * Returns a property based on the scheme path.
    */
    ChangesetHelper.getProperty = function (obj, path) {
        var current = obj;
        for (var i = 0; i < path.length; i++) {
            if (!current[path[i]]) {
                return null;
            }
            current = current[path[i]];
        }
        return current;
    };
    return ChangesetHelper;
}());
exports.default = ChangesetHelper;
